Low level API — pylm 0.14.1 documentation

# Low level API

If you are proficient in distributed computing, some of the key aspects of pylm may sound like the actor model. We are aware of this similarity, but we would rather use the term component, because pylm does not expose a programming paradigm. It’s just a framework with pieces to implement distributed systems.

Some concepts in this section may be hard, particularly if you don’t know how message queues work, ZeroMQ in particular. Before reading this section, it may be a good idea to read the ZeroMQ Guide.

- Building components from separate parts
  - The router
  - The parts
  - Services and connections
  - Bypass parts
- Using HTTP
- Turning a PALM master into a microservice